#
# spec file for package rsnapshot
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           rsnapshot
Version:        1.4.2
Release:        3.1
Summary:        Backup program using hardlinks
License:        GPL-2.0-or-later
Group:          Productivity/Archiving/Backup
URL:            http://www.rsnapshot.org/
Source0:        https://github.com/rsnapshot/rsnapshot/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        rsnapshot.logrotate
Patch1:         rsnapshot-config.patch
BuildRequires:  logrotate
BuildRequires:  openssh
BuildRequires:  perl
BuildRequires:  rsync
BuildRequires:  util-linux-systemd
Requires:       logrotate
Requires:       openssh
Requires:       perl
Requires:       rsync
Requires:       util-linux-systemd
BuildArch:      noarch

%description
rsnapshot is a filesystem snapshot utility for making backups of local
and remote systems. Using rsync and hard links, it is possible to keep
multiple, full backups instantly available. The disk space required is
just a little more than the space of one full backup, plus
incrementals. Depending on your configuration, it is quite possible to
set up in just a few minutes. Files can be restored by the users who
own them, without the root user getting involved. There are no tapes to
change, so once it's set up, you may never need to think about it
again.

%prep
%setup -q
%patch1

%build
# replace hardcoded /usr/local
find . -type f -exec sed -i "s|usr/local|usr|g" {} +
%configure
make %{?_smp_mflags}

%check
make %{?_smp_mflags} test

%install
%make_install
install -d "%{buildroot}/%{_sysconfdir}"
install -m 644 rsnapshot.conf.default "%{buildroot}/%{_sysconfdir}/rsnapshot.conf.default"
install -m 600 rsnapshot.conf.default "%{buildroot}/%{_sysconfdir}/rsnapshot.conf"
install -m 644 -D %{SOURCE1} "%{buildroot}/%{_sysconfdir}/logrotate.d/rsnapshot"

%files
%license COPYING
%doc AUTHORS ChangeLog README.md docs
%{_bindir}/rsnapshot
%{_bindir}/rsnapshot-diff
%config(noreplace) %{_sysconfdir}/rsnapshot.conf
%config %{_sysconfdir}/rsnapshot.conf.default
%config(noreplace) %{_sysconfdir}/logrotate.d/rsnapshot
%{_mandir}/man1/rsnapshot.1%{?ext_man}
%{_mandir}/man1/rsnapshot-diff.1%{?ext_man}

%changelog
* Mon Jun 11 2018 mpluskal@suse.com
- Modernise spec file with spec-cleaner
* Tue Jul  5 2016 Greg.Freemyer@gmail.com
- Add the docs subfolder to %%doc
* Tue Dec 22 2015 nico.kruber@gmail.com
- Update to 1.4.2
  * Fix double 8 bit shift bug introduced with github issue #65.
    Refs github issues #102, #103, #114, #118
    (bnc#987643)
* Fri Oct  2 2015 hpj@urpla.net
- add logrotate config and dependency for /var/log/rsnapshot
* Mon Sep 21 2015 mpluskal@suse.com
- Update to 1.4.1
  * Capture rsync's output right (Github issue 102)
- Changes for 1.4.0
  * Tidy the code with perltidy
  * Fix --rsh command line option
  * The --rsh option of rsync got errornously quoted (Debian Bug #743310)
  * Define traps to unmount LVM parts after fail If you use LVM
    snapshots and rsnapshot fails, rsnapshot will unmount and
    remove the snapshot, too.
  * cd to home before executing a command
  * if($use_lazy_deletes): remove lockfile in any case
  * Bail on failing cmd_(pre|post)exec If one of those commands
    fails, rsnapshot will exit with exit code != 0
  * Capture output from rsync and print/log if level is >=4
  * Print rsnpashot's PID when logging to syslog, instead of the
    logger's PID.
  * make script uses pod2man instead of /usr/bin/pod2man
  * rsnapshot-diff: Fixed removed files reported as addition (+ mark)
  * Introduction of backup_exec resource for running unix commands
    interspersed with backup and backup_script jobs.
  * check for SIGPIPE, mainly in case cron fails when trying to mail
    (this is probably why rsnapshot dies mysteriously if it outputs when
    called by cron on a system which does not have mail working).
  * add test case for -t showing --link-dest when there is only one snapshot
  * if gnu_cp_al fails, test out a simple cp -al command before suggesting
    that the cp does not support -al.
  * When snapshot_root does not exist, check existence of parent directories.
  * include_conf `command` now strips backticks before execution (bug fix
    based on suggestion from David Osborn).
  * Ignore extraneous output from lvremove command.  (patch by Tim Connors)
  * Update current maintainer status in Authors section of man page.
    (David Cantrell stepped down between 1.3.0 and 1.3.1.)
  * Remove some old (1.1.x -> 1.2.0) upgrade notices from man page.
  * Allow linux_lvm_cmd_* in config file to have options also.
  * Allow `backticks with options` in include_conf.
  * Fix inaccurate omission of --link-dest in test-mode output
  * rsnapshot-diff: Add -s option to show size of each file.
- Drop no longer needed patches
  * rsnapshot-1.3.1-perl5.18.patch
  * rsnapshot-1.3.1-no_usr_local.patch
* Sun Apr 12 2015 mpluskal@suse.com
- Use url for source
- Cleanup spec file with spec-cleaner
- Update dependencies
* Sun Dec 28 2014 bwiedemann@suse.com
- use explicit pathes for logger and ssh
  as autodetection at build-time goes wrong
* Thu Jul 25 2013 tchvatal@suse.com
- Split test phase to check one.
- Remove useless clean phase.
- Silence some rpmlint macros.
* Wed Jun 26 2013 Greg.Freemyer@gmail.com
- Add a patch to correct syntax needed by perl 5.18:
    rsnapshot-1.3.1-perl5.18.patch
- Get rid of changelog entries form specfile
* Thu Apr 16 2009 ro@suse.de
- buildfix: refresh patches
* Mon Sep  8 2008 hvogel@suse.de
- Update to 1.3.1
  * Fix help message mixup in lines between -c and -t
  * Allow named pipe as logfile
  * Include rsnapshot-copy script
  * Allow `backticks` in include_conf.
  * hopefully fix bug with link_dest not being used on second and
    later backups when you have link_dest 1 and sync_first 1
  * Added stop_on_stale_lockfile
  * Added multi-line config options
  * The 'interval' config option is now called 'retain'
* Thu Aug 16 2007 guru@unixtech.be
- added call to make test
- now requires perl-lchown
- changed sync_first configuration to default (0) instead of 1: http://www.linux-club.de/ftopic78019.html
* Wed May 23 2007 mskibbe@suse.de
- fix path to binary in man and info pages
* Mon Jan 15 2007 mskibbe@suse.de
- update to version 1.3.0 which
  o fix some bugs
  o includes some new and updated man-pages
  o includes more examples
  o Change "Perhaps this is not GNU cp?" error message
* Fri Jul  7 2006 mskibbe@suse.de
- create package
